\r wordpress
SET character_set_client = utf8;

DELIMITER |
DROP PROCEDURE IF EXISTS do_updates|
DROP PROCEDURE IF EXISTS do_wordpress_update_to351|
DROP PROCEDURE IF EXISTS do_wordpress_update_to361|
DROP PROCEDURE IF EXISTS update_db_version_to361|
DROP PROCEDURE IF EXISTS do_wordpress_update_to392|
DROP PROCEDURE IF EXISTS update_db_version_to392|

-- Creation of a procedure upgrading the wordpress database from v3.3.2 to v3.5.1
CREATE PROCEDURE do_updates()
BEGIN
	-- Check if wordpress version is lesser than 3.5.1
	IF((SELECT meta_value FROM wp_sitemeta WHERE meta_key='wpmu_upgrade_site')<22441) THEN
		CALL do_wordpress_update_to351();
	END IF;
	IF((SELECT meta_value FROM wp_sitemeta WHERE meta_key='wpmu_upgrade_site')<22448) THEN
		CALL do_wordpress_update_to361();
		CALL update_db_version_to361();
	END IF;

	-- Finally update to version 3.9.1
	IF((SELECT meta_value FROM wp_sitemeta WHERE meta_key='wpmu_upgrade_site')<27916) THEN
		CALL do_wordpress_update_to392();
		CALL update_db_version_to392();
	END IF;
END|

-- --------------------------------------------------------------------
-- Now is the time to declare the procs to upgrade wordpress to 3.9.1 |
-- --------------------------------------------------------------------
CREATE PROCEDURE update_db_version_to392()
BEGIN
	SET @db_version = '27916';

	versions: BEGIN
		DECLARE done_ids INT DEFAULT FALSE;
		DECLARE idb BIGINT;

		-- as we can have multiple blogs, we need to know the id wordpress gave them
		-- we create and use a cursor to do that

		DECLARE blog_ids CURSOR FOR SELECT blog_id FROM wp_blogs;
		DECLARE CONTINUE HANDLER FOR NOT FOUND SET done_ids=TRUE;

		OPEN blog_ids;

		-- we fetch `blog_ids` cursor in a loop

		read_ids: LOOP
		FETCH blog_ids INTO idb;
		IF done_ids THEN
			LEAVE read_ids;
		END IF;


		IF((SELECT COUNT(*) FROM wp_blog_versions WHERE blog_id=idb)>0) THEN

		-- if we got a record for the current id in `wp_blogs_versions` table, we update the db_version recorded

			UPDATE wp_blog_versions SET db_version=@db_version, last_updated=NOW();
		ELSE

		-- else, we insert a new record
		INSERT INTO wp_blog_versions (blog_id, db_version, last_updated) VALUES (idb, @db_version, NOW());
		END IF;
		END LOOP read_ids;
		CLOSE blog_ids;
	END versions;
	
	dbv: BEGIN
		DECLARE done INT DEFAULT FALSE;
		DECLARE a VARCHAR(64);
		DECLARE blog CURSOR FOR SELECT TABLE_NAME FROM information_schema.tables WHERE table_schema='wordpress' AND table_name like 'wp%_options';
		DECLARE CONTINUE HANDLER FOR NOT FOUND SET done = TRUE;

		OPEN blog;

		read_loop: LOOP
			FETCH blog INTO a;
			IF done THEN
				LEAVE read_loop;
			END IF;
		
		SET @prefix = SUBSTRING_INDEX(a, '_options',1);
		SET @cct2 = CONCAT('UPDATE ', a, ' SET option_value=',@db_version, ' WHERE option_name="db_version"');
		PREPARE stmt2 FROM @cct2;
		EXECUTE stmt2;
		DEALLOCATE PREPARE stmt2;

		END LOOP read_loop;
		CLOSE blog;
	END dbv;

		-- Update the `last_updated field` on blogs records
	UPDATE wp_blog_versions SET db_version=@db_version,last_updated=NOW();
	UPDATE wp_blogs SET last_updated=NOW();
	UPDATE wp_sitemeta SET meta_value=@db_version WHERE meta_key='wpmu_upgrade_site';
	UPDATE wp_options SET option_value=@db_version WHERE option_name='db_version';

END|


CREATE PROCEDURE do_wordpress_update_to392()
BEGIN
	-- First we delete the useless options of blogs
	opts: BEGIN
		DECLARE done INT DEFAULT FALSE;
		DECLARE a VARCHAR(64);
		DECLARE blogs CURSOR FOR SELECT TABLE_NAME FROM information_schema.tables WHERE table_schema='wordpress' AND table_name LIKE 'wp%_options';
		DECLARE CONTINUE HANDLER FOR NOT FOUND SET done = TRUE;

		open blogs;
		read_loop: LOOP
			FETCH blogs INTO a;
			IF done THEN
				LEAVE read_loop;
			END IF;
		SET @cct = CONCAT('DELETE FROM ', a,' WHERE option_name LIKE "links_recently_updated%"');
		PREPARE stmt FROM @cct;
		EXECUTE stmt;
		DEALLOCATE PREPARE stmt;

		SET @cct15 = CONCAT('DELETE FROM ', a, ' WHERE option_name="db_upgraded"');
		PREPARE stmt15 FROM @cct15;
		EXECUTE stmt15;
		DEALLOCATE PREPARE stmt15;

		SET @cct2 = CONCAT('INSERT INTO ', a, ' (option_name,option_value,autoload) VALUES ("db_upgraded","1","yes")');
		PREPARE stmt2 FROM @cct2;
		EXECUTE stmt2;
		DEALLOCATE PREPARE stmt2;

        -- Update of language : setup it to french by default

		SET @cct3 = CONCAT('UPDATE ', a,' SET option_value="fr_FR" WHERE option_name ="WPLANG"');
		PREPARE stmt3 FROM @cct3;
		EXECUTE stmt3;
		DEALLOCATE PREPARE stmt3;

		SET @cct3 = CONCAT('UPDATE ', a,' SET option_value="Europe/Paris" WHERE option_name ="timezone_string"');
		PREPARE stmt3 FROM @cct3;
		EXECUTE stmt3;
		DEALLOCATE PREPARE stmt3;

		END LOOP read_loop;
		CLOSE blogs;
	END opts;

	-- Alter on wp_signups

	ALTER TABLE wp_signups DROP KEY domain;
	ALTER TABLE wp_signups ADD KEY `user_email` (`user_email`);
	ALTER TABLE wp_signups ADD KEY `user_login_email` (`user_login`,`user_email`);
	ALTER TABLE wp_signups ADD KEY `domain_path` (`domain`,`path`);
	ALTER TABLE wp_signups ADD `signup_id` bigint(20) NOT NULL AUTO_INCREMENT PRIMARY KEY;


	

	-- Creation of all the buddypress tables
	--

	CREATE TABLE `wp_bp_activity_meta` (
	  `id` bigint(20) NOT NULL AUTO_INCREMENT,
	  `activity_id` bigint(20) NOT NULL,
	  `meta_key` varchar(255) DEFAULT NULL,
	  `meta_value` longtext,
	  PRIMARY KEY (`id`),
	  KEY `activity_id` (`activity_id`),
	  KEY `meta_key` (`meta_key`)
	) ENGINE=MyISAM DEFAULT CHARSET=utf8;

	CREATE TABLE `wp_bp_activity` (
	  `id` bigint(20) NOT NULL AUTO_INCREMENT,
	  `user_id` bigint(20) NOT NULL,
	  `component` varchar(75) NOT NULL,
	  `type` varchar(75) NOT NULL,
	  `action` text NOT NULL,
	  `content` longtext NOT NULL,
	  `primary_link` varchar(255) NOT NULL,
	  `item_id` bigint(20) NOT NULL,
	  `secondary_item_id` bigint(20) DEFAULT NULL,
	  `date_recorded` datetime NOT NULL,
	  `hide_sitewide` tinyint(1) DEFAULT '0',
	  `mptt_left` int(11) NOT NULL DEFAULT '0',
	  `mptt_right` int(11) NOT NULL DEFAULT '0',
	  `is_spam` tinyint(1) NOT NULL DEFAULT '0',
	  PRIMARY KEY (`id`),
	  KEY `date_recorded` (`date_recorded`),
	  KEY `user_id` (`user_id`),
	  KEY `item_id` (`item_id`),
	  KEY `secondary_item_id` (`secondary_item_id`),
	  KEY `component` (`component`),
	  KEY `type` (`type`),
	  KEY `mptt_left` (`mptt_left`),
	  KEY `mptt_right` (`mptt_right`),
	  KEY `hide_sitewide` (`hide_sitewide`),
	  KEY `is_spam` (`is_spam`)
	) ENGINE=MyISAM AUTO_INCREMENT=3 DEFAULT CHARSET=utf8;
	--
	-- Table structure for table `wp_bp_notifications`
	--

	CREATE TABLE `wp_bp_notifications` (
	  `id` bigint(20) NOT NULL AUTO_INCREMENT,
	  `user_id` bigint(20) NOT NULL,
	  `item_id` bigint(20) NOT NULL,
	  `secondary_item_id` bigint(20) DEFAULT NULL,
	  `component_name` varchar(75) NOT NULL,
	  `component_action` varchar(75) NOT NULL,
	  `date_notified` datetime NOT NULL,
	  `is_new` tinyint(1) NOT NULL DEFAULT '0',
	  PRIMARY KEY (`id`),
	  KEY `item_id` (`item_id`),
	  KEY `secondary_item_id` (`secondary_item_id`),
	  KEY `user_id` (`user_id`),
	  KEY `is_new` (`is_new`),
	  KEY `component_name` (`component_name`),
	  KEY `component_action` (`component_action`),
	  KEY `useritem` (`user_id`,`is_new`)
	) ENGINE=MyISAM DEFAULT CHARSET=utf8;

	--
	-- Table structure for table `wp_bp_user_blogs_blogmeta`
	--

	CREATE TABLE `wp_bp_user_blogs_blogmeta` (
	  `id` bigint(20) NOT NULL AUTO_INCREMENT,
	  `blog_id` bigint(20) NOT NULL,
	  `meta_key` varchar(255) DEFAULT NULL,
	  `meta_value` longtext,
	  PRIMARY KEY (`id`),
	  KEY `blog_id` (`blog_id`),
	  KEY `meta_key` (`meta_key`)
	) ENGINE=MyISAM AUTO_INCREMENT=43 DEFAULT CHARSET=utf8;
	--
	-- Table structure for table `wp_bp_user_blogs`
	--
	CREATE TABLE `wp_bp_user_blogs` (
	  `id` bigint(20) NOT NULL AUTO_INCREMENT,
	  `user_id` bigint(20) NOT NULL,
	  `blog_id` bigint(20) NOT NULL,
	  PRIMARY KEY (`id`),
	  KEY `user_id` (`user_id`),
	  KEY `blog_id` (`blog_id`)
	) ENGINE=MyISAM AUTO_INCREMENT=11771 DEFAULT CHARSET=utf8;


	--
	-- Table structure for table `wp_bp_xprofile_data`
	--

	CREATE TABLE `wp_bp_xprofile_data` (
	  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
	  `field_id` bigint(20) unsigned NOT NULL,
	  `user_id` bigint(20) unsigned NOT NULL,
	  `value` longtext NOT NULL,
	  `last_updated` datetime NOT NULL,
	  PRIMARY KEY (`id`),
	  KEY `field_id` (`field_id`),
	  KEY `user_id` (`user_id`)
	) ENGINE=MyISAM AUTO_INCREMENT=5 DEFAULT CHARSET=utf8;

	--
	-- Table structure for table `wp_bp_xprofile_fields`
	--

	CREATE TABLE `wp_bp_xprofile_fields` (
	  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
	  `group_id` bigint(20) unsigned NOT NULL,
	  `parent_id` bigint(20) unsigned NOT NULL,
	  `type` varchar(150) NOT NULL,
	  `name` varchar(150) NOT NULL,
	  `description` longtext NOT NULL,
	  `is_required` tinyint(1) NOT NULL DEFAULT '0',
	  `is_default_option` tinyint(1) NOT NULL DEFAULT '0',
	  `field_order` bigint(20) NOT NULL DEFAULT '0',
	  `option_order` bigint(20) NOT NULL DEFAULT '0',
	  `order_by` varchar(15) NOT NULL DEFAULT '',
	  `can_delete` tinyint(1) NOT NULL DEFAULT '1',
	  PRIMARY KEY (`id`),
	  KEY `group_id` (`group_id`),
	  KEY `parent_id` (`parent_id`),
	  KEY `field_order` (`field_order`),
	  KEY `can_delete` (`can_delete`),
	  KEY `is_required` (`is_required`)
	) ENGINE=MyISAM AUTO_INCREMENT=2 DEFAULT CHARSET=utf8;

	--
	-- Table structure for table `wp_bp_xprofile_groups`
	--

	CREATE TABLE `wp_bp_xprofile_groups` (
	  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
	  `name` varchar(150) NOT NULL,
	  `description` mediumtext NOT NULL,
	  `group_order` bigint(20) NOT NULL DEFAULT '0',
	  `can_delete` tinyint(1) NOT NULL,
	  PRIMARY KEY (`id`),
	  KEY `can_delete` (`can_delete`)
	) ENGINE=MyISAM AUTO_INCREMENT=2 DEFAULT CHARSET=utf8;

	CREATE TABLE `wp_bp_xprofile_meta` (
	  `id` bigint(20) NOT NULL AUTO_INCREMENT,
	  `object_id` bigint(20) NOT NULL,
	  `object_type` varchar(150) NOT NULL,
	  `meta_key` varchar(255) DEFAULT NULL,
	  `meta_value` longtext,
	  PRIMARY KEY (`id`),
	  KEY `object_id` (`object_id`),
	  KEY `meta_key` (`meta_key`)
	) ENGINE=MyISAM DEFAULT CHARSET=utf8;

END|

-- --------------------------------------------------------------------
-- Now is the time to declare the procs to upgrade wordpress to 3.6.1 |
-- --------------------------------------------------------------------


CREATE PROCEDURE update_db_version_to361()
BEGIN
	SET @db_version = '24448';

	versions: BEGIN
		DECLARE done_ids INT DEFAULT FALSE;
		DECLARE idb BIGINT;

		-- as we can have multiple blogs, we need to know the id wordpress gave them
		-- we create and use a cursor to do that

		DECLARE blog_ids CURSOR FOR SELECT blog_id FROM wp_blogs;
		DECLARE CONTINUE HANDLER FOR NOT FOUND SET done_ids=TRUE;

		OPEN blog_ids;

		-- we fetch `blog_ids` cursor in a loop

		read_ids: LOOP
		FETCH blog_ids INTO idb;
		IF done_ids THEN
			LEAVE read_ids;
		END IF;


		IF((SELECT COUNT(*) FROM wp_blog_versions WHERE blog_id=idb)>0) THEN

		-- if we got a record for the current id in `wp_blogs_versions` table, we update the db_version recorded

			UPDATE wp_blog_versions SET db_version=@db_version, last_updated=NOW();
		ELSE

		-- else, we insert a new record
			INSERT INTO wp_blog_versions (blog_id, db_version, last_updated) VALUES (idb, @db_version, NOW());
		END IF;
		END LOOP read_ids;
		CLOSE blog_ids;
	END versions;
	
	dbv: BEGIN
		DECLARE done INT DEFAULT FALSE;
		DECLARE a VARCHAR(64);
		DECLARE blog CURSOR FOR SELECT TABLE_NAME FROM information_schema.tables WHERE table_schema='wordpress' AND table_name like 'wp%_options';
		DECLARE CONTINUE HANDLER FOR NOT FOUND SET done = TRUE;

		OPEN blog;

		read_loop: LOOP
			FETCH blog INTO a;
			IF done THEN
				LEAVE read_loop;
			END IF;
		
		SET @prefix = SUBSTRING_INDEX(a, '_options',1);
		SET @cct2 = CONCAT('UPDATE ', a, ' SET option_value=',@db_version, ' WHERE option_name="db_version"');
		PREPARE stmt2 FROM @cct2;
		EXECUTE stmt2;
		DEALLOCATE PREPARE stmt2;

		END LOOP read_loop;
		CLOSE blog;
	END dbv;

	

	UPDATE wp_sitemeta SET meta_value=@db_version WHERE meta_key='wpmu_upgrade_site';
	UPDATE wp_options SET option_value=@db_version WHERE option_name='db_version';
END|


CREATE PROCEDURE do_wordpress_update_to361()
BEGIN
	SET @db_version = '24448';
        

		-- We drop the embed_autourls option
		DELETE FROM wp_options WHERE option_name='embed_autourls';
		-- Finally we update the `wpmu_upgrade_site` meta
		UPDATE wp_sitemeta SET meta_value=@db_version WHERE meta_key='wpmu_upgrade_site';
		UPDATE wp_options SET option_value=@db_version WHERE option_name='db_version';

		-- Changes for theming
		UPDATE wp_sitemeta SET meta_value='a:5:{s:6:"envole";s:7:"/themes";s:12:"twentyeleven";s:7:"/themes";s:9:"twentyten";s:7:"/themes";s:14:"twentythirteen";s:7:"/themes";s:12:"twentytwelve";s:7:"/themes";}' WHERE meta_key='_site_transient_theme_roots';
		UPDATE wp_sitemeta SET meta_value='a:6:{s:7:"classic";b:1;s:12:"twentyeleven";b:1;s:6:"envole";b:1;s:9:"twentyten";b:1;s:14:"twentythirteen";b:1;s:12:"twentytwelve";b:1;}' WHERE meta_key='allowedthemes';

		UPDATE wp_options SET option_value='Twenty Thirteen' WHERE (option_name='current_theme' AND option_value='Wordpress Classic');
END|
	
	

CREATE PROCEDURE do_wordpress_update_to351()
BEGIN
	IF((SELECT meta_value FROM wp_sitemeta WHERE meta_key='wpmu_upgrade_site')<22441) THEN
		-- The  new revision of the database is 22441

		SET @db_version ='22441';

		-- Here we start the block that will alter columns and keys of tables

		alters: BEGIN

			DECLARE done INT DEFAULT FALSE;

			-- a will hold the current value of our cursor 

			DECLARE a VARCHAR(64);

			-- as we can have multiple blogs on the same wordpress, we need to know how many we have
			-- and what is the prefix for each blog
			-- so we search for table wp*_options in information_schema.tables

			DECLARE blog CURSOR FOR SELECT TABLE_NAME FROM information_schema.tables WHERE table_schema='wordpress' AND table_name like 'wp%_options';

			DECLARE CONTINUE HANDLER FOR NOT FOUND SET done = TRUE;


			OPEN blog;

			-- we fetch `blog` cursor in a loop

			read_loop: LOOP
				FETCH blog INTO a;
				IF done THEN
					LEAVE read_loop;
				END IF;

				-- extraction of the prefix of the table (i.e : wp, wp_2, wp_3, etc...)

				SET @prefix = SUBSTRING_INDEX(a, '_options',1);

				-- we search if our current wp*_options have a `blog_id` in information schema

				IF((SELECT COUNT(*) FROM information_schema.columns WHERE table_name=a AND column_name='blog_id')>0) THEN

					-- if so, we drop that column

					SET @cct = CONCAT("ALTER TABLE ", a, " DROP COLUMN blog_id");
					PREPARE stmt FROM @cct;
					EXECUTE stmt;
					DEALLOCATE PREPARE stmt;

				END IF;

				-- we update the db_version option in current wp*_option tables

				SET @cct2 = CONCAT('UPDATE ', a, ' SET option_value=',@db_version, ' WHERE option_name="db_version"');
				PREPARE stmt2 FROM @cct2;
				EXECUTE stmt2;
				DEALLOCATE PREPARE stmt2;
			    
				-- we have to drop the `comment_approved` key if it exists in the wp*_comments tables
			    
				SET @comments_table = CONCAT(@prefix,'_comments');
				IF((SELECT COUNT(*) FROM information_schema.statistics WHERE index_schema='wordpress' AND table_name=@comments_table AND index_name='comment_approved')>0) THEN
					SET @cct_comments = CONCAT('ALTER TABLE ', @comments_table,' DROP KEY comment_approved');
					PREPARE stmt_comments FROM @cct_comments;
					EXECUTE stmt_comments;
					DEALLOCATE PREPARE stmt_comments;
				END IF;

				-- we modify the type of `post_content_filtered` field in the wp*_posts tables

				SET @posts_table = CONCAT(@prefix,'_posts');
				SET @cct_posts = CONCAT('ALTER TABLE ', @posts_table,' MODIFY post_content_filtered longtext');
				PREPARE stmt_posts FROM @cct_posts;
				EXECUTE stmt_posts;
				DEALLOCATE PREPARE stmt_posts;

			END LOOP read_loop;
			CLOSE blog;

		END alters;

		-- HERE WE ARE DONE WITH ALTERING TABLES


		-- Let's update the db_version everywhere else

		versions: BEGIN
			DECLARE done_ids INT DEFAULT FALSE;
			DECLARE idb BIGINT;

			-- as we can have multiple blogs, we need to know the id wordpress gave them
			-- we create and use a cursor to do that

			DECLARE blog_ids CURSOR FOR SELECT blog_id FROM wp_blogs;
			DECLARE CONTINUE HANDLER FOR NOT FOUND SET done_ids=TRUE;

			OPEN blog_ids;

			-- we fetch `blog_ids` cursor in a loop

			read_ids: LOOP
				FETCH blog_ids INTO idb;
				IF done_ids THEN
					LEAVE read_ids;
				END IF;


				IF((SELECT COUNT(*) FROM wp_blog_versions WHERE blog_id=idb)>0) THEN

					-- if we got a record for the current id in `wp_blogs_versions` table, we update the db_version recorded
				
					UPDATE wp_blog_versions SET db_version=@db_version, last_updated=NOW();
				ELSE
				
					-- else, we insert a new record
					INSERT INTO wp_blog_versions (blog_id, db_version, last_updated) VALUES (idb, @db_version, NOW());
				END IF;
			END LOOP read_ids;
			CLOSE blog_ids;
		END versions;
		
		-- Finally we update the `wpmu_upgrade_site` meta
		
		UPDATE wp_sitemeta SET meta_value=@db_version WHERE meta_key='wpmu_upgrade_site';
	END IF;
END|

CALL do_updates()|

DROP PROCEDURE IF EXISTS do_wordpress_update_to351|
DROP PROCEDURE IF EXISTS do_wordpress_update_to361|
DROP PROCEDURE IF EXISTS do_updates|
DROP PROCEDURE IF EXISTS do_wordpress_update_to392|
DROP PROCEDURE IF EXISTS update_db_version_to361|
DROP PROCEDURE IF EXISTS update_db_version_to392|
